package com.yiqi.core.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.ClothType;

/**
 * 衣服种类Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface IClothTypeService extends IService<ClothType> {
    /**
     * 查询衣服种类
     *
     * @param id 衣服种类主键
     * @return 衣服种类
     */
    public ClothType selectClothTypeById(Long id);

    /**
     * 查询衣服种类列表
     *
     * @param clothType 衣服种类
     * @return 衣服种类集合
     */
    public List<ClothType> selectClothTypeList(ClothType clothType);

    /**
     * 新增衣服种类
     *
     * @param clothType 衣服种类
     * @return 结果
     */
    public int insertClothType(ClothType clothType);

    /**
     * 修改衣服种类
     *
     * @param clothType 衣服种类
     * @return 结果
     */
    public int updateClothType(ClothType clothType);

    /**
     * 批量删除衣服种类
     *
     * @param ids 需要删除的衣服种类主键集合
     * @return 结果
     */
    public int deleteClothTypeByIds(Long[] ids);

    /**
     * 删除衣服种类信息
     *
     * @param id 衣服种类主键
     * @return 结果
     */
    public int deleteClothTypeById(Long id);

    /**
     * 修改衣服种类状态
     *
     * @param clothType 衣服种类
     * @return 结果
     */
    public int updateTypeStatus(ClothType clothType);
}
